"use client"

import { useState } from "react"
import type { Store } from "@/types"
import { Button } from "@/components/ui/button"
import { Input } from "@/components/ui/input"
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card"
import { ScrollArea } from "@/components/ui/scroll-area"
import { StoreIcon, Plus, Trash2, ShoppingBag, Building, Building2, Home, StoreIcon as StoreIconAlt } from 'lucide-react'
import { useLanguage } from "@/contexts/language-context"
import { motion } from "framer-motion"
import {
  AlertDialog,
  AlertDialogAction,
  AlertDialogCancel,
  AlertDialogContent,
  AlertDialogDescription,
  AlertDialogFooter,
  AlertDialogHeader,
  AlertDialogTitle,
  AlertDialogTrigger,
} from "@/components/ui/alert-dialog"
import { Badge } from "@/components/ui/badge"

interface StoreManagerProps {
  stores: Store[]
  addStore: (name: string) => void
  deleteStore: (id: string) => void
  selectedStoreId: string | null
  setSelectedStoreId: (id: string | null) => void
}

// Array of store icons to randomly assign to stores
const storeIcons = [
  { icon: ShoppingBag, color: "text-emerald-500" },
  { icon: Building, color: "text-teal-500" },
  { icon: Building2, color: "text-green-500" },
  { icon: Home, color: "text-emerald-600" },
  { icon: StoreIconAlt, color: "text-teal-600" },
]

const StoreManager: React.FC<StoreManagerProps> = ({
  stores,
  addStore,
  deleteStore,
  selectedStoreId,
  setSelectedStoreId,
}) => {
  const { t } = useLanguage()
  const [newStoreName, setNewStoreName] = useState("")
  const [storeToDelete, setStoreToDelete] = useState<Store | null>(null)
  const [isAdding, setIsAdding] = useState(false)

  const handleAddStore = (e: React.FormEvent) => {
    e.preventDefault()
    if (newStoreName.trim()) {
      addStore(newStoreName)
      setNewStoreName("")
      setIsAdding(false)
    }
  }

  const openDeleteConfirmation = (store: Store) => {
    setStoreToDelete(store)
  }

  const confirmDelete = () => {
    if (storeToDelete) {
      deleteStore(storeToDelete.id)
      setStoreToDelete(null)
    }
  }

  // Function to get a consistent icon for a store based on its ID
  const getStoreIcon = (storeId: string) => {
    const index = storeId.charCodeAt(0) % storeIcons.length
    return storeIcons[index]
  }

  return (
    <Card className="shadow-lg border-0 bg-white dark:bg-slate-900 overflow-hidden">
      <CardHeader className="bg-gradient-to-r from-emerald-600 to-teal-600 text-white pb-4">
        <CardTitle className="flex items-center gap-2 text-xl">
          <StoreIcon className="h-5 w-5" /> {t("stores") || "My Stores"}
        </CardTitle>
        <p className="text-sm text-emerald-50 mt-1 opacity-90">
          {t("manageStores") || "Manage your shopping locations"}
        </p>
      </CardHeader>
      <CardContent className="p-0">
        <div className="p-4 bg-emerald-50 dark:bg-slate-800/50">
          {isAdding ? (
            <motion.form
              initial={{ opacity: 0, y: -10 }}
              animate={{ opacity: 1, y: 0 }}
              onSubmit={handleAddStore}
              className="flex flex-col gap-2"
            >
              <div className="flex gap-2">
                <Input
                  type="text"
                  value={newStoreName}
                  onChange={(e) => setNewStoreName(e.target.value)}
                  placeholder={t("enterStoreName") || "Store name"}
                  className="flex-grow border-emerald-200 focus-visible:ring-emerald-500"
                  autoFocus
                />
                <Button
                  type="submit"
                  size="sm"
                  className="bg-emerald-600 hover:bg-emerald-700 text-white"
                  disabled={!newStoreName.trim()}
                >
                  {t("add") || "Add"}
                </Button>
              </div>
              <div className="flex justify-end">
                <Button
                  type="button"
                  variant="ghost"
                  size="sm"
                  onClick={() => setIsAdding(false)}
                  className="text-sm text-slate-600 dark:text-slate-400 hover:text-slate-900"
                >
                  {t("cancel") || "Cancel"}
                </Button>
              </div>
            </motion.form>
          ) : (
            <Button
              onClick={() => setIsAdding(true)}
              className="w-full bg-white hover:bg-emerald-50 text-emerald-700 border border-emerald-200 hover:border-emerald-300 dark:bg-slate-800 dark:text-emerald-400 dark:border-slate-700 dark:hover:bg-slate-700"
            >
              <Plus className="mr-2 h-4 w-4" />
              {t("addStore") || "Add New Store"}
            </Button>
          )}
        </div>

        <div className="px-4 py-3 border-b border-slate-200 dark:border-slate-700 flex justify-between items-center">
          <h3 className="font-medium text-sm text-slate-500 dark:text-slate-400">
            {t("yourStores") || "Your Stores"}
          </h3>
          <Badge variant="outline" className="text-xs font-normal">
            {stores.length} {stores.length === 1 ? t("store") || "store" : t("stores") || "stores"}
          </Badge>
        </div>

        <ScrollArea className="h-[280px]">
          {stores.length === 0 ? (
            <div className="flex flex-col items-center justify-center h-[200px] text-center p-4">
              <div className="w-16 h-16 rounded-full bg-emerald-100 dark:bg-emerald-900/30 flex items-center justify-center mb-3">
                <ShoppingBag className="h-8 w-8 text-emerald-500 dark:text-emerald-400" />
              </div>
              <p className="text-sm text-slate-600 dark:text-slate-400 mb-1">
                {t("noStores") || "No stores yet"}
              </p>
              <p className="text-xs text-slate-500 dark:text-slate-500">
                {t("addStoreToStart") || "Add your first store to get started"}
              </p>
            </div>
          ) : (
            <ul className="divide-y divide-slate-100 dark:divide-slate-800">
              {stores.map((store) => {
                const storeIcon = getStoreIcon(store.id)
                const StoreIconComponent = storeIcon.icon
                return (
                  <motion.li
                    key={store.id}
                    initial={{ opacity: 0 }}
                    animate={{ opacity: 1 }}
                    exit={{ opacity: 0 }}
                    whileHover={{ backgroundColor: "rgba(236, 253, 245, 0.4)" }}
                    className={`flex items-center justify-between p-3 cursor-pointer transition-all ${selectedStoreId === store.id
                        ? "bg-emerald-50 dark:bg-emerald-900/20 border-l-4 border-emerald-500"
                        : "border-l-4 border-transparent"
                      }`}
                    onClick={() => setSelectedStoreId(store.id)}
                  >
                    <div className="flex items-center gap-3">
                      <div
                        className={`w-10 h-10 rounded-lg flex items-center justify-center ${selectedStoreId === store.id
                            ? "bg-emerald-100 dark:bg-emerald-800/50"
                            : "bg-slate-100 dark:bg-slate-800"
                          }`}
                      >
                        <StoreIconComponent
                          className={`h-5 w-5 ${selectedStoreId === store.id ? "text-emerald-600 dark:text-emerald-400" : storeIcon.color
                            }`}
                        />
                      </div>
                      <div>
                        <p
                          className={`font-medium ${selectedStoreId === store.id
                              ? "text-emerald-800 dark:text-emerald-400"
                              : "text-slate-700 dark:text-slate-300"
                            }`}
                        >
                          {store.name}
                        </p>
                        <p className="text-xs text-slate-500 dark:text-slate-500">
                          {t("clickToSelect") || "Click to select"}
                        </p>
                      </div>
                    </div>

                    <AlertDialog>
                      <AlertDialogTrigger asChild>
                        <Button
                          variant="ghost"
                          size="icon"
                          className="text-slate-400 hover:text-red-500 hover:bg-red-50 dark:hover:bg-red-900/20"
                          onClick={(e) => {
                            e.stopPropagation()
                            openDeleteConfirmation(store)
                          }}
                          aria-label={`${t("deleteStore") || "Delete store"} ${store.name}`}
                        >
                          <Trash2 size={16} />
                        </Button>
                      </AlertDialogTrigger>
                      <AlertDialogContent>
                        <AlertDialogHeader>
                          <AlertDialogTitle>{t("deleteStoreConfirm") || "Delete Store?"}</AlertDialogTitle>
                          <AlertDialogDescription>
                            {t("deleteStoreWarning")?.replace("{name}", storeToDelete?.name || "") ||
                              `This will permanently delete "${storeToDelete?.name}" and all its items. This action cannot be undone.`}
                          </AlertDialogDescription>
                        </AlertDialogHeader>
                        <AlertDialogFooter>
                          <AlertDialogCancel onClick={() => setStoreToDelete(null)}>
                            {t("cancel") || "Cancel"}
                          </AlertDialogCancel>
                          <AlertDialogAction
                            onClick={confirmDelete}
                            className="bg-red-500 hover:bg-red-600 text-white"
                          >
                            {t("delete") || "Delete"}
                          </AlertDialogAction>
                        </AlertDialogFooter>
                      </AlertDialogContent>
                    </AlertDialog>
                  </motion.li>
                )
              })}
            </ul>
          )}
        </ScrollArea>
      </CardContent>
    </Card>
  )
}

export default StoreManager
